<template>
    <hr>
    <div class="my-2 attachments">
        <div class="flex flex-row">
            <div class="mb-2 ms-2 my-auto">Attachments</div>
            <div v-if="props.object?.attachment?.length > 3" class="ms-auto">
                <button 
                    @click="openAttachments"
                    class="attachment-btn"
                >
                    <div class="flex flex-row items-center">
                        <svg 
                            xmlns="http://www.w3.org/2000/svg" 
                            width="32" height="32" 
                            fill="#7646fc" 
                            viewBox="0 0 256 256"
                            :class="{ 'rotate-180': isOpen == '0' }"
                            class="transition-transform duration-300"
                        >
                            <path d="M128,24A104,104,0,1,0,232,128,104.11,104.11,0,0,0,128,24Zm45.66,125.66a8,8,0,0,1-11.32,0L128,115.31,93.66,149.66a8,8,0,0,1-11.32-11.32l40-40a8,8,0,0,1,11.32,0l40,40A8,8,0,0,1,173.66,149.66Z"/>
                        </svg>
                        <div class="my-auto font-medium ps-1">
                            {{ isOpen == '1' ? 'Show less' : 'Show more' }}
                        </div>
                    </div>
                </button>
            </div>
        </div>

        <div class="flex flex-col flex-wrap gap-2">
            <div v-if="props.object?.attachment.length <= 3" v-for="(attachment, index) in props.object?.attachment" :key="index">
                <component :is="getAttachmentComponent(attachment.attachment_file_type)" :attachments="attachment" />
            </div>
            <div v-else>
                <div v-for="(attachment, index) in props.object?.attachment.slice(0,3)" :key="index">
                    <component :is="getAttachmentComponent(attachment.attachment_file_type)" :attachments="attachment" />
                </div>
                <transition name="expand">
                    <div v-show="isOpen == '1'">
                        <div v-for="(attachment, index) in props.object?.attachment.slice(3)" :key="index">
                            <component :is="getAttachmentComponent(attachment.attachment_file_type)" :attachments="attachment" />
                        </div>
                    </div>
                </transition>
            </div>
        </div>
    </div>
</template>

<script setup lang="ts">
import { ref } from "vue";
import AttachmentImage from "../Email/Attachment/Image.vue";
import AttachmentDocument from "../Email/Attachment/Document.vue";
import AttachmentZIP from "../Email/Attachment/ZIP.vue";
import AttachmentVideo from "../Email/Attachment/Video.vue";

interface Props {
    object?: any;
}

const props = withDefaults(defineProps<Props>(), { object: null });

const isOpen = ref('0');

function openAttachments()
{
    if(isOpen.value == '0'){
        isOpen.value = '1'
    }
    else if(isOpen.value == '1'){
        isOpen.value = '0'
    }
}

const getAttachmentComponent = (type: string) => {
    const components = {
        IMAGE: AttachmentImage,
        DOCUMENT: AttachmentDocument,
        ZIP: AttachmentZIP,
        VIDEO: AttachmentVideo,
        OTHERS: AttachmentDocument
    };
    return components[type] || AttachmentDocument;
};
</script>

<style scoped>
.attachment-btn {
    border: none;
    color: #7646FC;
    padding: 2px 10px;
    margin: 0;
    border-radius: 16px;
    font-size: 12px;
    line-height: 1;
    cursor: pointer;
    display: flex;
    align-items: center;
}

/* Chevron rotation */
.rotate-180 {
    transform: rotate(180deg);
}

.expand-enter, .expand-leave-to {
    max-height: 0;
    opacity: 0;
}

.expand-enter-to, .expand-leave {
    max-height: 500px;
    opacity: 1;
}
</style>
